diff --git mitmproxy/proxy/protocol/http2.py mitmproxy/proxy/protocol/http2.py
index a6e8a4dd9..c1812b3da 100644
--- mitmproxy/proxy/protocol/http2.py
+++ mitmproxy/proxy/protocol/http2.py
@@ -188,7 +188,7 @@ def _handle_data_received(self, eid, event, source_conn):
             self.streams[eid].kill()
             self.connections[source_conn].safe_reset_stream(
                 event.stream_id,
-                h2.errors.REFUSED_STREAM
+                h2.errors.ErrorCodes.REFUSED_STREAM
             )
             self.log("HTTP body too large. Limit is {}.".format(bsl), "info")
         else:
@@ -207,7 +207,7 @@ def _handle_stream_ended(self, eid):
 
     def _handle_stream_reset(self, eid, event, is_server, other_conn):
         self.streams[eid].kill()
-        if eid in self.streams and event.error_code == h2.errors.CANCEL:
+        if eid in self.streams and event.error_code == h2.errors.ErrorCodes.CANCEL:
             if is_server:
                 other_stream_id = self.streams[eid].client_stream_id
             else:
@@ -228,7 +228,7 @@ def _handle_connection_terminated(self, event, is_server):
             event.last_stream_id,
             event.additional_data), "info")
 
-        if event.error_code != h2.errors.NO_ERROR:
+        if event.error_code != h2.errors.ErrorCodes.NO_ERROR:
             # Something terrible has happened - kill everything!
             self.connections[self.client_conn].close_connection(
                 error_code=event.error_code,
diff --git test/mitmproxy/proxy/protocol/test_http2.py test/mitmproxy/proxy/protocol/test_http2.py
index 1f695cc5f..23027c242 100644
--- test/mitmproxy/proxy/protocol/test_http2.py
+++ test/mitmproxy/proxy/protocol/test_http2.py
@@ -36,7 +36,11 @@ class _Http2ServerBase(net_tservers.ServerTestBase):
     class handler(mitmproxy.net.tcp.BaseHandler):
 
         def handle(self):
-            h2_conn = h2.connection.H2Connection(client_side=False, header_encoding=False)
+            config = h2.config.H2Configuration(
+                client_side=False,
+                validate_outbound_headers=False,
+                validate_inbound_headers=False)
+            h2_conn = h2.connection.H2Connection(config)
 
             preamble = self.rfile.read(24)
             h2_conn.initiate_connection()
@@ -138,7 +142,11 @@ def _setup_connection(self):
 
         client.convert_to_ssl(alpn_protos=[b'h2'])
 
-        h2_conn = h2.connection.H2Connection(client_side=True, header_encoding=False)
+        config = h2.config.H2Configuration(
+            client_side=True,
+            validate_outbound_headers=False,
+            validate_inbound_headers=False)
+        h2_conn = h2.connection.H2Connection(config)
         h2_conn.initiate_connection()
         client.wfile.write(h2_conn.data_to_send())
         client.wfile.flush()
@@ -756,7 +764,7 @@ class TestMaxConcurrentStreams(_Http2Test):
     @classmethod
     def setup_class(cls):
         _Http2TestBase.setup_class()
-        _Http2ServerBase.setup_class(h2_server_settings={h2.settings.MAX_CONCURRENT_STREAMS: 2})
+        _Http2ServerBase.setup_class(h2_server_settings={h2.settings.SettingCodes.MAX_CONCURRENT_STREAMS: 2})
 
     @classmethod
     def handle_server_event(cls, event, h2_conn, rfile, wfile):
